@@ -17,11 +17,11 @@ DBGp::Client - simple client for the DBGp debugger protocol
         # but has side-effects in the condition
         $command = 'require Data::Dumper; print Data::Dumper::Dumper($var);';
         $res = $client->send_command(
-            'breakpoiint_set', '-t', 'conditional',
-                               '-f', 'file:///path/to/file.pl',
-                               '-n', $line,
-                               '--',
-                               encode_base64("$command; 0"),
+            'breakpoint_set', '-t', 'conditional',
+                              '-f', 'file:///path/to/file.pl',
+                              '-n', $line,
+                              '--',
+                              encode_base64("$command; 0"),
         );
         die $res->message if $res->is_error;
 
@@ -41,7 +41,7 @@ documentation.
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 1;
 
@@ -53,7 +53,7 @@ Mattia Barbon <mbarbon@cpan.org>
 
 =head1 LICENSE
 
-Copyright (c) 2015 Mattia Barbon. All rights reserved.
+Copyright (c) 2015-2016 Mattia Barbon. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
